@@ -98,7 +98,7 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 			: (pDock->container.iMouseY < 0
 			||
 		pDock->container.iMouseY >= (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight))));*/
-	double x1, x2, y1, y2;
+	int x1, x2, y1, y2;
 	if (pDock->iInputState == CAIRO_DOCK_INPUT_ACTIVE)
 	{
 		x1 = 0;
@@ -106,14 +106,14 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 		if (pDock->container.bDirectionUp)
 		{
 			///y1 = (pDock->fMagnitudeMax != 0 ? 0 : pDock->container.iHeight - pDock->iMinDockHeight);
-			y1 = pDock->container.iHeight - pDock->iActiveHeight;
+			y1 = pDock->container.iHeight - pDock->iActiveHeight + 1;
 			y2 = pDock->container.iHeight;
 		}
 		else
 		{
 			y1 = 0;
 			///y2 = (pDock->fMagnitudeMax != 0 ? pDock->container.iHeight : pDock->iMinDockHeight);
-			y2 = pDock->iActiveHeight;
+			y2 = pDock->iActiveHeight - 1;
 		}
 	}
 	else if (pDock->iInputState == CAIRO_DOCK_INPUT_AT_REST)
@@ -122,13 +122,13 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 		x2 = (pDock->container.iWidth + pDock->iMinDockWidth) / 2;
 		if (pDock->container.bDirectionUp)
 		{
-			y1 = pDock->container.iHeight - pDock->iMinDockHeight;
+			y1 = pDock->container.iHeight - pDock->iMinDockHeight + 1;
 			y2 = pDock->container.iHeight;
 		}
 		else
 		{
 			y1 = 0;
-			y2 = pDock->iMinDockHeight;
+			y2 = pDock->iMinDockHeight - 1;
 		}		
 	}
 	else  // hidden
@@ -136,8 +136,8 @@ static gboolean _mouse_is_really_outside (CairoDock *pDock)
 	if (pDock->container.iMouseX <= x1
 	|| pDock->container.iMouseX >= x2)
 		return TRUE;
-	if (pDock->container.iMouseY <= y1
-	|| pDock->container.iMouseY >= y2)
+	if (pDock->container.iMouseY < y1
+	|| pDock->container.iMouseY > y2)  // Note: Compiz has a bug: when using the "cube rotation" plug-in, it will reserve 2 pixels for itself on the left and right edges of the screen. So the mouse is not inside the dock when it's at x=0 or x=Ws-1 (no 'enter' event is sent; it's as if the x=0 or x=Ws-1 vertical line of pixels is out of the screen).
 		return TRUE;	
 	
 	return FALSE;
@@ -479,8 +479,6 @@ gboolean cairo_dock_on_motion_notify (GtkWidget* pWidget,
 	static double fLastTime = 0;
 	if (s_bFrozenDock && pMotion != NULL && pMotion->time != 0)
 		return FALSE;
-	if (pDock->bMenuVisible)
-		return FALSE;
 	Icon *pPointedIcon=NULL, *pLastPointedIcon = cairo_dock_get_pointed_icon (pDock->icons);
 	int iLastMouseX = pDock->container.iMouseX;
 	//g_print ("%s (%.2f;%.2f, %d)\n", __func__, pMotion->x, pMotion->y, pDock->iInputState);
@@ -662,8 +660,8 @@ gboolean cairo_dock_on_leave_dock_notification (gpointer data, CairoDock *pDock,
 	
 	//g_print ("%s (%d, %d)\n", __func__, pDock->iRefCount, pDock->bMenuVisible);
 	
-	//\_______________ On quitte si le menu est leve, pour rester en position haute.
-	if (pDock->bMenuVisible)
+	//\_______________ If a modal window is raised, we discard the 'leave-event' to stay in the up position.
+	if (pDock->bHasModalWindow)
 		return CAIRO_DOCK_INTERCEPT_NOTIFICATION;
 	
 	//\_______________ On gere le drag d'une icone hors du dock.
@@ -745,7 +743,7 @@ gboolean cairo_dock_on_leave_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 	
 	//\_______________ On ignore les signaux errones venant d'un WM buggue (Kwin) ou meme de X (changement de bureau).
 	//if (pEvent)
-	//	//g_print ("leave event: %d;%d; %d;%d; %d; %d\n", (int)pEvent->x, (int)pEvent->y, (int)pEvent->x_root, (int)pEvent->y_root, pEvent->mode, pEvent->detail);
+		//g_print ("leave event: %d;%d; %d;%d; %d; %d\n", (int)pEvent->x, (int)pEvent->y, (int)pEvent->x_root, (int)pEvent->y_root, pEvent->mode, pEvent->detail);
 	if (pEvent && (pEvent->x != 0 ||  pEvent->y != 0 || pEvent->x_root != 0 || pEvent->y_root != 0))  // strange leave events occur (detail = GDK_NOTIFY_NONLINEAR, nil coordinates); let's ignore them!
 	{
 		if (pDock->container.bIsHorizontal)
@@ -763,10 +761,10 @@ gboolean cairo_dock_on_leave_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 	{
 		//g_print ("forced leave event: %d;%d\n", pDock->container.iMouseX, pDock->container.iMouseY);
 	}
-	if (pEvent && !_mouse_is_really_outside(pDock))  // check that the mouse is really outside (only if the request comes from the Window Manager; this is to work around buggy WM like KWin).
+	if (/**pEvent && */!_mouse_is_really_outside(pDock))  // check that the mouse is really outside (the request might not come from the Window Manager, for instance if we deactivate the menu; this also works around buggy WM like KWin).
 	{
 		//g_print ("not really outside (%d;%d ; %d/%d)\n", pDock->container.iMouseX, pDock->container.iMouseY, pDock->iMaxDockHeight, pDock->iMinDockHeight);
-		if (pDock->iSidTestMouseOutside == 0 && pEvent)  // si l'action induit un changement de bureau, ou une appli qui bloque le focus (gksu), X envoit un signal de sortie alors qu'on est encore dans le dock, et donc n'en n'envoit plus lorsqu'on en sort reellement. On teste donc pendant qques secondes apres l'evenement.
+		if (pDock->iSidTestMouseOutside == 0 && pEvent && ! pDock->bHasModalWindow)  // si l'action induit un changement de bureau, ou une appli qui bloque le focus (gksu), X envoit un signal de sortie alors qu'on est encore dans le dock, et donc n'en n'envoit plus lorsqu'on en sort reellement. On teste donc pendant qques secondes apres l'evenement. C'est ausi vrai pour l'affichage d'un menu/dialogue interactif, mais comme on envoie nous-meme un signal de sortie lorsque le menu disparait, il est inutile de le faire ici.
 		{
 			//g_print ("start checking mouse\n");
 			pDock->iSidTestMouseOutside = g_timeout_add (500, (GSourceFunc)_check_mouse_outside, pDock);
@@ -909,6 +907,7 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 		return FALSE;
 	}*/
 	
+	gboolean bWasInside = pDock->container.bInside;
 	pDock->container.bInside = TRUE;
 	
 	// animation d'entree.
@@ -967,8 +966,11 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 		cairo_dock_start_showing (pDock);  // on a mis a jour la zone d'input avant, sinon la fonction le ferait, ce qui serait inutile.
 	}
 	
+	// start growing up (do it before calculating icons, so that we don't seem to be in an anormal state, where we're inside a dock that doesn't grow).
+	cairo_dock_start_growing (pDock);
+	
 	// since we've just entered the dock, the pointed icon has changed from none to the current one.
-	if (pEvent != NULL)
+	if (pEvent != NULL && ! bWasInside)
 	{
 		// update the mouse coordinates
 		if (pDock->container.bIsHorizontal)
@@ -989,8 +991,6 @@ gboolean cairo_dock_on_enter_notify (GtkWidget* pWidget, GdkEventCrossing* pEven
 			cairo_dock_on_change_icon (NULL, icon, pDock);  // we were out of the dock, so there is no previous pointed icon.
 		}
 	}
-	// on lance le grossissement.
-	cairo_dock_start_growing (pDock);
 	
 	return TRUE;
 }
@@ -1038,7 +1038,7 @@ static gboolean _double_click_delay_over (Icon *icon)
 static gboolean _check_mouse_outside (CairoDock *pDock)  // ce test est principalement fait pour detecter les cas ou X nous envoit un signal leave errone alors qu'on est dedans (=> sortie refusee, bInside reste a TRUE), puis du coup ne nous en envoit pas de leave lorsqu'on quitte reellement le dock.
 {
 	//g_print ("%s (%d, %d, %d)\n", __func__, pDock->bIsShrinkingDown, pDock->iMagnitudeIndex, pDock->container.bInside);
-	if (pDock->bIsShrinkingDown || pDock->iMagnitudeIndex == 0 || ! pDock->container.bInside)  // cas triviaux : si le dock est deja retrecit, ou qu'on est deja plus dedans, on peut quitter.
+	if (pDock->bIsShrinkingDown || pDock->iMagnitudeIndex == 0 || ! pDock->container.bInside)  // trivial cases : if the dock has already shrunk, or we're not inside any more, we can quit the loop.
 	{
 		pDock->iSidTestMouseOutside = 0;
 		return FALSE;
