@@ -221,8 +221,17 @@ static gboolean on_button_press_dialog (GtkWidget* pWidget,
 	CairoDialog *pDialog)
 {
 	//g_print ("press button on dialog\n");
-	if (pButton->time > pDialog->iButtonPressTime)  // it's not a click on the interactive widget that has been passed to the dialog.
+	if (pButton->button == 1 && pButton->time > pDialog->iButtonPressTime)  // left-click, and not a click on the interactive widget that has been passed to the dialog.
 	{
+		// the interactive widget may have holes (for instance, a gtk-calendar); ignore them, otherwise it's really easy to close the dialog unexpectedly.
+		if (pDialog->pInteractiveWidget)
+		{
+			GtkAllocation allocation;
+			gtk_widget_get_allocation (pDialog->pInteractiveWidget, &allocation);
+			if (pButton->x >= allocation.x && pButton->x <= allocation.x + allocation.width
+			&& pButton->y >= allocation.y && pButton->y <= allocation.y + allocation.height)  // the click is inside the widget.
+				return FALSE;
+		}
 		if (pButton->type == GDK_BUTTON_PRESS)
 		{
 			if (pDialog->pButtons == NULL)  // not a dialog that can be closed by a button => we close it here
@@ -527,7 +536,13 @@ gboolean cairo_dock_dialog_unreference (CairoDialog *pDialog)
 				CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
 				//g_print ("leave from container %x\n", pContainer);
 				if (pContainer)
+				{
+					if (CAIRO_DOCK_IS_DOCK (pContainer) && gtk_window_get_modal (GTK_WINDOW (pDialog->container.pWidget)))
+					{
+						CAIRO_DOCK (pContainer)->bHasModalWindow = FALSE;
+					}
 					cairo_dock_emit_leave_signal (pContainer);
+				}
 				
 				if (pIcon->iHideLabel > 0)
 				{
@@ -848,11 +863,9 @@ CairoDialog *cairo_dock_show_dialog_full (const gchar *cText, Icon *pIcon, Cairo
 	attr.pUserData = data;
 	attr.pFreeDataFunc = pFreeDataFunc;
 	attr.iTimeLength = (int) fTimeLength;
+	const gchar *cDefaultActionButtons[3] = {"ok", "cancel", NULL};
 	if (pActionFunc != NULL)
-	{
-		const gchar *cButtons[3] = {"ok", "cancel", NULL};
-		attr.cButtonsImage = cButtons;
-	}
+		attr.cButtonsImage = cDefaultActionButtons;
 	
 	CairoDialog *pDialog = cairo_dock_build_dialog (&attr, pIcon, pContainer);
 	return pDialog;
@@ -1147,8 +1160,13 @@ void cairo_dock_hide_dialog (CairoDialog *pDialog)
 			CairoContainer *pContainer = cairo_dock_search_container_from_icon (pIcon);
 			//g_print ("leave from container %x\n", pContainer);
 			if (pContainer)
+			{
+				if (CAIRO_DOCK_IS_DOCK (pContainer) && gtk_window_get_modal (GTK_WINDOW (pDialog->container.pWidget)))
+				{
+					CAIRO_DOCK (pContainer)->bHasModalWindow = FALSE;
+				}
 				cairo_dock_emit_leave_signal (pContainer);
-			
+			}
 			if (pIcon->iHideLabel > 0)
 			{
 				pIcon->iHideLabel --;
@@ -1178,6 +1196,10 @@ void cairo_dock_unhide_dialog (CairoDialog *pDialog)
 					gtk_widget_queue_draw (pContainer->pWidget);
 				pIcon->iHideLabel ++;
 			}
+			if (CAIRO_DOCK_IS_DOCK (pContainer) && gtk_window_get_modal (GTK_WINDOW (pDialog->container.pWidget)))
+			{
+				CAIRO_DOCK (pContainer)->bHasModalWindow = TRUE;
+			}
 		}
 	}
 	pDialog->bPositionForced = FALSE;
