@@ -25,11 +25,6 @@
 #include <string.h>
 #include <glib/gstdio.h>
 
-#ifdef HAVE_GLITZ
-#include <gdk/gdkx.h>
-#include <glitz-glx.h>
-#include <cairo-glitz.h>
-#endif
 
 #include "cairo-dock-icon-facility.h"  // cairo_dock_compare_icons_order
 #include "cairo-dock-config.h"  // cairo_dock_update_conf_file
@@ -42,7 +37,7 @@
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-themes-manager.h"  // cairo_dock_mark_current_theme_as_modified
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
-#include "cairo-dock-animations.h"  // cairo_dock_launch_animation
+//#include "cairo-dock-animations.h"  // cairo_dock_launch_animation
 #include "cairo-dock-launcher-factory.h"  // cairo_dock_new_launcher_icon
 #include "cairo-dock-separator-manager.h"  // cairo_dock_create_separator_surface
 #include "cairo-dock-X-utilities.h"  // cairo_dock_show_xwindow
@@ -58,17 +53,17 @@ static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRender
 	CairoDock *pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 	if (pParentDock == NULL)
 	{
-		cd_message ("le dock parent (%s) n'existe pas, on le cree", icon->cParentDockName);
-		pParentDock = cairo_dock_create_dock (icon->cParentDockName, NULL);
+		cd_message ("The parent dock (%s) doesn't exist: we create it", icon->cParentDockName);
+		pParentDock = cairo_dock_create_dock (icon->cParentDockName);
 	}
 	
 	//\____________ On cree son sous-dock si necessaire.
 	if (icon->iTrueType == CAIRO_DOCK_ICON_TYPE_CONTAINER && icon->cName != NULL)
 	{
 		CairoDock *pChildDock = cairo_dock_search_dock_from_name (icon->cName);
-		if (pChildDock && pChildDock->iRefCount > 0 && pChildDock != icon->pSubDock)  // un sous-dock de meme nom existe deja, on change le nom de l'icone.
+		if (pChildDock && (pChildDock->iRefCount > 0 || pChildDock->bIsMainDock))  // un sous-dock de meme nom existe deja, on change le nom de l'icone.
 		{
-			gchar *cUniqueDockName = cairo_dock_get_unique_dock_name ("New sub-dock");
+			gchar *cUniqueDockName = cairo_dock_get_unique_dock_name (icon->cName);
 			cd_warning ("A sub-dock with the same name (%s) already exists, we'll change it to %s", icon->cName, cUniqueDockName);
 			gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
 			cairo_dock_update_conf_file (cDesktopFilePath,
@@ -81,20 +76,17 @@ static CairoDock *_cairo_dock_handle_container (Icon *icon, const gchar *cRender
 		}
 		if (pChildDock == NULL)
 		{
-			cd_message ("le dock fils (%s) n'existe pas, on le cree avec la vue %s", icon->cName, cRendererName);
-			icon->pSubDock = cairo_dock_create_subdock_from_scratch (NULL, icon->cName, pParentDock);
+			cd_message ("The child dock (%s) doesn't exist, we create it with this view: %s", icon->cName, cRendererName);
+			pChildDock = cairo_dock_create_subdock (icon->cName, cRendererName, pParentDock, NULL);
 		}
-		else if (pChildDock != icon->pSubDock)
+		else
 		{
-			cairo_dock_reference_dock (pChildDock, pParentDock);
-			icon->pSubDock = pChildDock;
-			cd_message ("le dock devient un dock fils (%d, %d)", pChildDock->container.bIsHorizontal, pChildDock->container.bDirectionUp);
-		}
-		if (cRendererName != NULL && icon->pSubDock != NULL)
-		{
-			cairo_dock_set_renderer (icon->pSubDock, cRendererName);
-			cairo_dock_update_dock_size (icon->pSubDock);
+			cd_message ("The dock is now a 'child-dock' (%d, %d)", pChildDock->container.bIsHorizontal, pChildDock->container.bDirectionUp);
+			cairo_dock_main_dock_to_sub_dock (pChildDock, pParentDock, cRendererName);
 		}
+		icon->pSubDock = pChildDock;
+		if (icon->iSubdockViewType != 0)
+			cairo_dock_trigger_redraw_subdock_content_on_icon (icon);
 	}
 	
 	return pParentDock;
@@ -111,7 +103,7 @@ static void _load_launcher (Icon *icon)
 	}
 	else if (icon->cFileName)  // icone possedant une image, on affiche celle-ci.
 	{
-		gchar *cIconPath = cairo_dock_search_icon_s_path (icon->cFileName);
+		gchar *cIconPath = cairo_dock_search_icon_s_path (icon->cFileName, MAX (iWidth, iHeight));
 		if (cIconPath != NULL && *cIconPath != '\0')
 			icon->pIconBuffer = cairo_dock_create_surface_from_image_simple (cIconPath,
 				iWidth,
@@ -128,7 +120,7 @@ static void _load_user_separator (Icon *icon)
 	icon->pIconBuffer = NULL;
 	if (icon->cFileName != NULL)
 	{
-		gchar *cIconPath = cairo_dock_search_icon_s_path (icon->cFileName);
+		gchar *cIconPath = cairo_dock_search_icon_s_path (icon->cFileName, MAX (iWidth, iHeight));
 		if (cIconPath != NULL && *cIconPath != '\0')
 		{
 			icon->pIconBuffer = cairo_dock_create_surface_from_image_simple (cIconPath,
@@ -204,7 +196,7 @@ Icon * cairo_dock_create_icon_from_desktop_file (const gchar *cDesktopFileName)
 	g_free (cRendererName);
 	
 	//\____________ On remplit ses buffers.
-	cairo_dock_trigger_load_icon_buffers (icon, CAIRO_CONTAINER (pParentDock));
+	///cairo_dock_trigger_load_icon_buffers (icon);
 	
 	//\____________ On gere son role d'inhibiteur.
 	cd_message ("+ %s/%s", icon->cName, icon->cClass);
@@ -239,7 +231,7 @@ Icon * cairo_dock_create_dummy_launcher (gchar *cName, gchar *cFileName, gchar *
 }
 
 
-void cairo_dock_build_docks_tree_with_desktop_files (const gchar *cDirectory)
+void cairo_dock_load_launchers_from_dir (const gchar *cDirectory)
 {
 	cd_message ("%s (%s)", __func__, cDirectory);
 	GDir *dir = g_dir_open (cDirectory, 0, NULL);
@@ -266,8 +258,7 @@ void cairo_dock_build_docks_tree_with_desktop_files (const gchar *cDirectory)
 			pParentDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
 			if (pParentDock != NULL)  // a priori toujours vrai.
 			{
-				cairo_dock_insert_icon_in_dock_full (icon, pParentDock, ! CAIRO_DOCK_UPDATE_DOCK_SIZE, ! CAIRO_DOCK_ANIMATE_ICON, ! CAIRO_DOCK_INSERT_SEPARATOR, NULL);
-				/// synchroniser icon->pSubDock avec pParentDock ?...
+				cairo_dock_insert_icon_in_dock_full (icon, pParentDock, ! CAIRO_DOCK_ANIMATE_ICON, ! CAIRO_DOCK_INSERT_SEPARATOR, NULL);
 			}
 		}
 	}
@@ -284,34 +275,44 @@ void cairo_dock_reload_launcher (Icon *icon)
 		return ;
 	}
 	
-	//\_____________ Ensure sub-dock's name unicity.
+	//\_____________ Rename sub-dock and ensure sub-dock's name unicity before we reload the icon.
 	if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))
 	{
+		// get the new name of the icon (and therefore of its sub-dock).
 		gchar *cDesktopFilePath = g_strdup_printf ("%s/%s", g_cCurrentLaunchersPath, icon->cDesktopFileName);
 		GKeyFile* pKeyFile = cairo_dock_open_key_file (cDesktopFilePath);
 		g_return_if_fail (pKeyFile != NULL);
+		gchar *cName = g_key_file_get_string (pKeyFile, "Desktop Entry", "Name", NULL);
 		
-		if (CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (icon))  // on assure l'unicite du nom du sous-dock ici, car cela n'est volontairement pas fait dans la fonction de creation de l'icone.
+		// set a default name if none.
+		if (cName == NULL || *cName == '\0')  // no name defined, we need one.
 		{
-			gchar *cName = g_key_file_get_string (pKeyFile, "Desktop Entry", "Name", NULL);
-			if (cName == NULL || *cName == '\0')
-				cName = g_strdup ("dock");
-			if (icon->cName == NULL || strcmp (icon->cName, cName) != 0)  // le nom a change.
-			{
-				gchar *cUniqueName = cairo_dock_get_unique_dock_name (cName);
-				if (strcmp (cName, cUniqueName) != 0)
-				{
-					g_key_file_set_string (pKeyFile, "Desktop Entry", "Name", cUniqueName);
-					cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
-					cd_debug ("on renomme a l'avance le sous-dock en %s", cUniqueName);
-					if (icon->pSubDock != NULL)
-						cairo_dock_rename_dock (icon->cName, icon->pSubDock, cUniqueName);  // on le renomme ici pour eviter de transvaser dans un nouveau dock (ca marche aussi ceci dit).
-				}
-				g_free (cUniqueName);
-			}
-			g_free (cName);
+			if (icon->cName != NULL)
+				cName = g_strdup (icon->cName);
+			else
+				cName = cairo_dock_get_unique_dock_name ("sub-dock");
+			g_key_file_set_string (pKeyFile, "Desktop Entry", "Name", cName);
+			cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
 		}
 		
+		// if it has changed, ensure its unicity, and rename the sub-dock to be able to link with it again.
+		if (icon->cName == NULL || strcmp (icon->cName, cName) != 0)  // name has changed -> rename the sub-dock.
+		{
+			// ensure unicity
+			gchar *cUniqueName = cairo_dock_get_unique_dock_name (cName);
+			if (strcmp (cName, cUniqueName) != 0)
+			{
+				g_key_file_set_string (pKeyFile, "Desktop Entry", "Name", cUniqueName);
+				cairo_dock_write_keys_to_file (pKeyFile, cDesktopFilePath);
+			}
+			// rename sub-dock
+			cd_debug ("on renomme a l'avance le sous-dock en %s", cUniqueName);
+			if (icon->pSubDock != NULL)
+				cairo_dock_rename_dock (icon->cName, icon->pSubDock, cUniqueName);  // on le renomme ici pour eviter de transvaser dans un nouveau dock (ca marche aussi ceci dit).
+			g_free (cUniqueName);
+		}
+		g_free (cName);
+		
 		g_key_file_free (pKeyFile);
 		g_free (cDesktopFilePath);
 	}
@@ -322,30 +323,57 @@ void cairo_dock_reload_launcher (Icon *icon)
 	CairoDock *pDock = cairo_dock_search_dock_from_name (cPrevDockName);  // changement de l'ordre ou du container.
 	double fOrder = icon->fOrder;
 	
-	CairoDock *pSubDock = icon->pSubDock;
-	///icon->pSubDock = NULL;
 	gchar *cClass = icon->cClass;
 	icon->cClass = NULL;
 	gchar *cDesktopFileName = icon->cDesktopFileName;
 	icon->cDesktopFileName = NULL;
 	gchar *cName = icon->cName;
 	icon->cName = NULL;
-	gchar *cRendererName = NULL;
-	if (pSubDock != NULL)
-	{
-		cRendererName = pSubDock->cRendererName;
-		pSubDock->cRendererName = NULL;
-	}
 	
-	//\_____________ On recharge l'icone.
+	//\_____________ get its new params.
 	gchar *cSubDockRendererName = NULL;
 	cairo_dock_load_icon_info_from_desktop_file (cDesktopFileName, icon, &cSubDockRendererName);
 	g_return_if_fail (icon->cDesktopFileName != NULL);
 	
-	CairoDock *pNewDock = _cairo_dock_handle_container (icon, cSubDockRendererName);
-	g_free (cSubDockRendererName);
+	// get its (possibly new) container.
+	CairoDock *pNewDock = cairo_dock_search_dock_from_name (icon->cParentDockName);
+	if (pNewDock == NULL)
+	{
+		cd_message ("The parent dock (%s) doesn't exist, we create it", icon->cParentDockName);
+		pNewDock = cairo_dock_create_dock (icon->cParentDockName);
+	}
 	g_return_if_fail (pNewDock != NULL);
 	
+	//\_____________ manage the change of container or order.
+	if (pDock != pNewDock)  // container has changed.
+	{
+		// on la detache de son container actuel et on l'insere dans le nouveau.
+		gchar *tmp = icon->cParentDockName;  // le detach_icon remet a 0 ce champ, il faut le donc conserver avant.
+		icon->cParentDockName = NULL;
+		cairo_dock_detach_icon_from_dock_full (icon, pDock, TRUE);
+		
+		cairo_dock_insert_icon_in_dock (icon, pNewDock, CAIRO_DOCK_ANIMATE_ICON);  // le remove et le insert vont declencher le redessin de l'icone pointant sur l'ancien et le nouveau sous-dock le cas echeant.
+		icon->cParentDockName = tmp;
+	}
+	else  // same container, but different order.
+	{
+		if (icon->fOrder != fOrder)  // On gere le changement d'ordre.
+		{
+			pNewDock->icons = g_list_remove (pNewDock->icons, icon);
+			pNewDock->icons = g_list_insert_sorted (pNewDock->icons,
+				icon,
+				(GCompareFunc) cairo_dock_compare_icons_order);
+			cairo_dock_update_dock_size (pDock);  // -> recalculate icons and update input shape
+		}
+		// on redessine l'icone pointant sur le sous-dock, pour le cas ou l'ordre et/ou l'image du lanceur aurait change.
+		if (pNewDock->iRefCount != 0)
+		{
+			cairo_dock_redraw_subdock_content (pNewDock);
+		}
+	}
+	
+	//\_____________ reload icon
+	// redraw icon
 	if (icon->pSubDock != NULL && icon->iSubdockViewType != 0)  // petite optimisation : vu que la taille du lanceur n'a pas change, on evite de detruire et refaire sa surface.
 	{
 		cairo_dock_draw_subdock_content_on_icon (icon, pNewDock);
@@ -355,84 +383,25 @@ void cairo_dock_reload_launcher (Icon *icon)
 		cairo_dock_reload_icon_image (icon, CAIRO_CONTAINER (pNewDock));
 	}
 	
-	//g_print ("icon : %.1fx%.1f", icon->fWidth, icon->fHeight);
-	
+	// reload label
 	if (cName && ! icon->cName)
 		icon->cName = g_strdup (" ");
 	
 	if (cairo_dock_strings_differ (cName, icon->cName))
 		cairo_dock_load_icon_text (icon, &myIconsParam.iconTextDescription);
 	
-	//\_____________ On gere son sous-dock.
-	if (icon->Xid != 0)
+	// set sub-dock renderer
+	if (icon->pSubDock != NULL)  // son rendu a pu changer.
 	{
-		if (icon->pSubDock == NULL)
-			icon->pSubDock = pSubDock;
-		else  // ne devrait pas arriver (une icone de container n'est pas un lanceur pouvant prendre un Xid).
-			cairo_dock_destroy_dock (pSubDock, cName);
-	}
-	else
-	{
-		if (pSubDock != NULL && pSubDock != icon->pSubDock)  // ca n'est plus le meme container, on transvase ou on detruit.
+		if (cairo_dock_strings_differ (cSubDockRendererName, icon->pSubDock->cRendererName))
 		{
-			cd_debug ("on transvase dans le nouveau sous-dock");
-			cairo_dock_remove_icons_from_dock (pSubDock, icon->pSubDock, icon->cName);
-			cairo_dock_destroy_dock (pSubDock, cName);
-			pSubDock = NULL;
-		}
-	}
-	
-	if (icon->pSubDock != NULL && pSubDock == icon->pSubDock)  // c'est le meme sous-dock, son rendu a pu changer.
-	{
-		if (cairo_dock_strings_differ (cRendererName, icon->pSubDock->cRendererName))
+			cairo_dock_set_renderer (icon->pSubDock, cSubDockRendererName);
 			cairo_dock_update_dock_size (icon->pSubDock);
-		cairo_dock_synchronize_one_sub_dock_orientation (pSubDock, pNewDock, TRUE);
-	}
-
-	//\_____________ On gere le changement de container ou d'ordre.
-	//g_print ("%x -> %x\n", pDock, pNewDock);
-	if (pDock != pNewDock)  // changement de container.
-	{
-		// on la detache de son container actuel et on l'insere dans le nouveau.
-		gchar *tmp = icon->cParentDockName;  // le detach_icon remet a 0 ce champ, il faut le donc conserver avant.
-		icon->cParentDockName = NULL;
-		cairo_dock_detach_icon_from_dock (icon, pDock, TRUE);
-		if (pDock->icons == NULL && pDock->iRefCount == 0 && ! pDock->bIsMainDock)  // le dock devient vide, il se fera detruire automatiquement.
-		{
-			pDock = NULL;
 		}
-		else
-		{
-			cairo_dock_update_dock_size (pDock);
-			cairo_dock_calculate_dock_icons (pDock);
-			gtk_widget_queue_draw (pDock->container.pWidget);
-		}
-		cairo_dock_insert_icon_in_dock (icon, pNewDock, CAIRO_DOCK_UPDATE_DOCK_SIZE, CAIRO_DOCK_ANIMATE_ICON);  // le remove et le insert vont declencher le redessin de l'icone pointant sur l'ancien et le nouveau sous-dock le cas echeant.
-		cairo_dock_launch_animation (CAIRO_CONTAINER (pNewDock));
-		icon->cParentDockName = tmp;
-	}
-	else  // le container est identique, on gere juste le changement d'ordre.
-	{
-		icon->fWidth *= pNewDock->container.fRatio / pDock->container.fRatio;
-		icon->fHeight *= pNewDock->container.fRatio / pDock->container.fRatio;
-		if (icon->fOrder != fOrder)  // On gere le changement d'ordre.
-		{
-			pNewDock->pFirstDrawnElement = NULL;
-			pNewDock->icons = g_list_remove (pNewDock->icons, icon);
-			pNewDock->icons = g_list_insert_sorted (pNewDock->icons,
-				icon,
-				(GCompareFunc) cairo_dock_compare_icons_order);
-			cairo_dock_update_dock_size (pDock);  // la largeur max peut avoir ete influencee par le changement d'ordre.
-		}
-		// on redessine l'icone pointant sur le sous-dock, pour le cas ou l'ordre et/ou l'image du lanceur aurait change.
-		if (pNewDock->iRefCount != 0)
-		{
-			cairo_dock_redraw_subdock_content (pNewDock);
-		}
-		///cairo_dock_trigger_refresh_launcher_gui ();  // a faire par l'app
 	}
+	g_free (cSubDockRendererName);
 	
-	//\_____________ On gere l'inhibition de sa classe.
+	//\_____________ handle class inhibition.
 	gchar *cNowClass = icon->cClass;
 	if (cClass != NULL && (cNowClass == NULL || strcmp (cNowClass, cClass) != 0))  // la classe a change, on desinhibe l'ancienne.
 	{
@@ -444,15 +413,14 @@ void cairo_dock_reload_launcher (Icon *icon)
 	if (myTaskbarParam.bMixLauncherAppli && cNowClass != NULL && (cClass == NULL || strcmp (cNowClass, cClass) != 0))  // la classe a change, on inhibe la nouvelle.
 		cairo_dock_inhibite_class (cNowClass, icon);
 
-	//\_____________ On redessine les docks impactes.
-	cairo_dock_calculate_dock_icons (pNewDock);
+	//\_____________ redraw dock.
+	///cairo_dock_calculate_dock_icons (pNewDock);
 	cairo_dock_redraw_container (CAIRO_CONTAINER (pNewDock));
 
 	g_free (cPrevDockName);
 	g_free (cClass);
 	g_free (cDesktopFileName);
 	g_free (cName);
-	g_free (cRendererName);
 	cairo_dock_mark_current_theme_as_modified (TRUE);
 }
 
